
<?php
//=============================
//== show System information ==
//=============================

require_once("./class.php");

getSysInfo($sysInfo);

?>

<html>
<head>
<meta content="text/html; charset=UTF-8" http-equiv="content-type">
<title></title>
</head>

<body>
	<br>
	<form method="post" name="form1"><!-- 加入 action="aa.html" 可以指定給誰處理 -->
		<table align="center" border="1" cellpadding="2" cellspacing="2" width="600">
		<tbody>

		<tr align="center">
			<td colspan="2" bgcolor="#ffcc99">Device Information<br></td>
		</tr>

		<tr>
			<td bgcolor="#ccffff" width="200">Product Name</td>
			<td ><?php echo $sysInfo["name"] ?><br></td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Serial Number</td>
			<td ><?php echo $sysInfo["sn"] ?><br></td>
		</tr>

		<tr>
			<td bgcolor="#ccffff">Kernel Version</td>
			<td ><?php echo $sysInfo["os_kernel_ver"] ?><br></td>
		</tr>

		</tbody>
		</table>

		<br>
		<br>
	</form>

	<br>
	<br>
</body>
</html>
